#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-pem
version:              0.3.0
visibility:           public
id:                   crypton-pem-0.3.0-JR3twaSc055B9HMynUaY2O
key:                  crypton-pem-0.3.0-JR3twaSc055B9HMynUaY2O
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:
    Mike Pilgrem <public@pilgrem.com>,
    Kazu Yamamoto <kazu@iij.ad.jp>

author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/mpilgrem/crypton-pem
synopsis:             Privacy Enhanced Mail (PEM) file format reader and writer.
description:
    A library to read and write files in the Privacy Enhanced Mail (PEM) format.

category:             Data
abi:                  8a1c0fe78cc334f43b6ecca3c945d78c
exposed:              True
exposed-modules:      Data.PEM
hidden-modules:       Data.PEM.Parser Data.PEM.Types Data.PEM.Writer
import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-pem-0.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-pem-0.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-pem-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-pem
hs-libraries:         HScrypton-pem-0.3.0-JR3twaSc055B9HMynUaY2O
depends:
    base-4.18.2.1 base64-1.0-Iz7IcUZUjIALi0PtVtksmK bytestring-0.11.5.3
    deepseq-1.4.8.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-crypton-pem/html/crypton-pem.haddock
haddock-html:         /usr/share/doc/haskell-crypton-pem/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

